@@ -1,13 +1,12 @@
 r"""
-.. _absorbed-spectral-model:
+.. _absorption-spectral-model:
 
-Absorbed Spectral Model
-=======================
+EBL Absorbption Spectral Model
+==============================
 
 This model evaluates absorbed spectral model.
 
-The spectral model is evaluated, and then multiplied with an EBL
-absorption factor given by
+The EBL absorption factor given by
 
 .. math::
     \exp{ \left ( -\alpha \times \tau(E, z) \right )}
@@ -26,15 +25,36 @@ redshift z of the source, and :math:`\alpha` is a scale factor
 from astropy import units as u
 import matplotlib.pyplot as plt
 from gammapy.modeling.models import (
-    AbsorbedSpectralModel,
-    Absorption,
+    EBLAbsorptionNormSpectralModel,
     Models,
     PowerLawSpectralModel,
     SkyModel,
 )
 
-redshift = 0.117
-absorption = Absorption.read_builtin("dominguez")
+# Here we illustrate how to create and plot EBL absorption models for a redshift of 0.5
+# sphinx_gallery_thumbnail_number = 1
+
+redshift = 0.5
+dominguez = EBLAbsorptionNormSpectralModel.read_builtin("dominguez", redshift=redshift)
+franceschini = EBLAbsorptionNormSpectralModel.read_builtin(
+    "franceschini", redshift=redshift
+)
+finke = EBLAbsorptionNormSpectralModel.read_builtin("finke", redshift=redshift)
+
+plt.figure()
+energy_range = [0.08, 3] * u.TeV
+opts = dict(energy_range=energy_range, energy_unit="TeV", flux_unit="")
+franceschini.plot(label="Franceschini 2008", **opts)
+finke.plot(label="Finke 2010", **opts)
+dominguez.plot(label="Dominguez 2011", **opts)
+
+plt.ylabel(r"Absorption coefficient [$\exp{(-\tau(E))}$]")
+plt.xlim(energy_range.value)
+plt.ylim(1e-4, 2)
+plt.title(f"EBL models (z={redshift})")
+plt.grid(which="both")
+plt.legend(loc="best")
+
 
 # Spectral model corresponding to PKS 2155-304 (quiescent state)
 index = 3.53
@@ -42,12 +62,14 @@ amplitude = 1.81 * 1e-12 * u.Unit("cm-2 s-1 TeV-1")
 reference = 1 * u.TeV
 pwl = PowerLawSpectralModel(index=index, amplitude=amplitude, reference=reference)
 
-# EBL + PWL model
-model = AbsorbedSpectralModel(
-    spectral_model=pwl, absorption=absorption, redshift=redshift
-)
+# The power-law model is multiplied by the EBL norm spectral model
+redshift = 0.117
+absorption = EBLAbsorptionNormSpectralModel.read_builtin("dominguez", redshift=redshift)
+
+model = pwl * absorption
 
 energy_range = [0.1, 100] * u.TeV
+plt.figure()
 model.plot(energy_range)
 plt.grid(which="both")
 plt.ylim(1e-24, 1e-8)
