@@ -1,4 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import copy
+from operator import le, lt
 import numpy as np
 from astropy.table import Table, vstack
 from astropy.time import Time
@@ -59,7 +61,7 @@ class GTI:
         self.table = table
 
     def copy(self):
-        return self.__class__(self.table)
+        return copy.deepcopy(self)
 
     @classmethod
     def create(cls, start, stop, reference_time="2000-01-01"):
@@ -74,8 +76,8 @@ class GTI:
         reference_time : `~astropy.time.Time`
             the reference time to use in GTI definition
         """
-        start = np.atleast_1d(Quantity(start))
-        stop = np.atleast_1d(Quantity(stop))
+        start = Quantity(start, ndmin=1)
+        stop = Quantity(stop, ndmin=1)
         reference_time = Time(reference_time)
         meta = time_ref_to_dict(reference_time)
         table = Table({"START": start.to("s"), "STOP": stop.to("s")}, meta=meta)
@@ -140,6 +142,37 @@ class GTI:
         met = Quantity(self.table["STOP"].astype("float64"), "second")
         return self.time_ref + met
 
+    @property
+    def time_intervals(self):
+        """List of time intervals"""
+        return [
+            (t_start, t_stop)
+            for t_start, t_stop in zip(self.time_start, self.time_stop)
+        ]
+
+    @classmethod
+    def from_time_intervals(cls, time_intervals, reference_time="2000-01-01"):
+        """From list of time intervals
+
+        Parameters
+        ----------
+        time_intervals : list of `~astropy.time.Time` objects
+            Time intervals
+        reference_time : `~astropy.time.Time`
+            Reference time to use in GTI definition
+
+        Returns
+        -------
+        gti : `GTI`
+            GTI table.
+        """
+        reference_time = Time(reference_time)
+        start = Time([_[0] for _ in time_intervals]) - reference_time
+        stop = Time([_[1] for _ in time_intervals]) - reference_time
+        meta = time_ref_to_dict(reference_time)
+        table = Table({"START": start.to("s"), "STOP": stop.to("s")}, meta=meta)
+        return cls(table=table)
+
     def select_time(self, time_interval):
         """Select and crop GTIs in time interval.
 
@@ -174,7 +207,7 @@ class GTI:
         return self.__class__(gti_within)
 
     def stack(self, other):
-        """Stack with another GTI.
+        """Stack with another GTI in place.
 
         This simply changes the time reference of the second GTI table
         and stack the two tables. No logic is applied to the intervals.
@@ -184,23 +217,24 @@ class GTI:
         other : `~gammapy.data.GTI`
             GTI to stack to self
 
-        Returns
-        -------
-        new_gti : `~gammapy.data.GTI`
-            New GTI
         """
         start = (other.time_start - self.time_ref).sec
         end = (other.time_stop - self.time_ref).sec
         table = Table({"START": start, "STOP": end}, names=["START", "STOP"])
-        return self.__class__(vstack([self.table, table]))
+        self.table = vstack([self.table, table])
 
-    def union(self):
+    def union(self, overlap_ok=True, merge_equal=True):
         """Union of overlapping time intervals.
 
         Returns a new `~gammapy.data.GTI` object.
 
-        Intervals that touch will be merged, e.g.
-        ``(1, 2)`` and ``(2, 3)`` will result in ``(1, 3)``.
+        Parameters
+        ----------
+        overlap_ok : bool
+            Whether to raise an error when overlapping time bins are found.
+        merge_equal : bool
+            Whether to merge touching time bins e.g. ``(1, 2)`` and ``(2, 3)``
+            will result in ``(1, 3)``.
         """
         # Algorithm to merge overlapping intervals is well-known,
         # see e.g. https://stackoverflow.com/a/43600953/498873
@@ -208,15 +242,71 @@ class GTI:
         table = self.table.copy()
         table.sort("START")
 
+        compare = lt if merge_equal else le
+
         # We use Python dict instead of astropy.table.Row objects,
         # because on some versions modifying Row entries doesn't behave as expected
         merged = [{"START": table[0]["START"], "STOP": table[0]["STOP"]}]
         for row in table[1:]:
             interval = {"START": row["START"], "STOP": row["STOP"]}
-            if merged[-1]["STOP"] <= interval["START"]:
+            if compare(merged[-1]["STOP"], interval["START"]):
                 merged.append(interval)
             else:
+                if not overlap_ok:
+                    raise ValueError("Overlapping time bins")
+
                 merged[-1]["STOP"] = max(interval["STOP"], merged[-1]["STOP"])
 
         merged = Table(rows=merged, names=["START", "STOP"], meta=self.table.meta)
         return self.__class__(merged)
+
+    def group_table(self, time_intervals, atol="1e-6 s"):
+        """Compute the table with the info on the group to which belong each time interval.
+
+        The t_start and t_stop are stored in MJD from a scale in "utc".
+
+        Parameters
+        ----------
+        time_intervals : list of `astropy.time.Time`
+            Start and stop time for each interval to compute the LC
+        atol : `~astropy.units.Quantity`
+            Tolerance value for time comparison with different scale. Default 1e-6 sec.
+
+        Returns
+        -------
+        group_table : `~astropy.table.Table`
+            Contains the grouping info.
+        """
+        atol = Quantity(atol)
+
+        group_table = Table(
+            names=("group_idx", "time_min", "time_max", "bin_type"),
+            dtype=("i8", "f8", "f8", "S10"),
+        )
+        time_intervals_lowedges = Time(
+            [time_interval[0] for time_interval in time_intervals]
+        )
+        time_intervals_upedges = Time(
+            [time_interval[1] for time_interval in time_intervals]
+        )
+
+        for t_start, t_stop in zip(self.time_start, self.time_stop):
+            mask1 = t_start >= time_intervals_lowedges - atol
+            mask2 = t_stop <= time_intervals_upedges + atol
+            mask = mask1 & mask2
+            if np.any(mask):
+                group_index = np.where(mask)[0]
+                bin_type = ""
+            else:
+                group_index = -1
+                if np.any(mask1):
+                    bin_type = "overflow"
+                elif np.any(mask2):
+                    bin_type = "underflow"
+                else:
+                    bin_type = "outflow"
+            group_table.add_row(
+                [group_index, t_start.utc.mjd, t_stop.utc.mjd, bin_type]
+            )
+
+        return group_table
