@@ -7,7 +7,7 @@ from astropy.table import Table
 from astropy.time import Time
 from gammapy.data import GTI
 from gammapy.datasets import Datasets, SpectrumDataset, SpectrumDatasetOnOff
-from gammapy.irf import EDispKernel, EffectiveAreaTable
+from gammapy.irf import EDispKernelMap, EffectiveAreaTable
 from gammapy.maps import MapAxis, RegionGeom, RegionNDMap, WcsGeom
 from gammapy.modeling import Fit
 from gammapy.modeling.models import (
@@ -31,6 +31,7 @@ from gammapy.utils.time import time_ref_to_dict
 
 @pytest.fixture()
 def spectrum_dataset():
+    name = "test"
     energy = np.logspace(-1, 1, 31) * u.TeV
     livetime = 100 * u.s
 
@@ -41,11 +42,14 @@ def spectrum_dataset():
     temp_mod = ConstantTemporalModel()
 
     model = SkyModel(spectral_model=pwl, temporal_model=temp_mod, name="test-source")
-    aeff = EffectiveAreaTable.from_constant(energy, "1 cm2")
-
     axis = MapAxis.from_edges(energy, interp="log", name="energy")
+    axis_true = MapAxis.from_edges(energy, interp="log", name="energy_true")
+
     background = RegionNDMap.create(region="icrs;circle(0, 0, 0.1)", axes=[axis])
 
+    models = Models([model])
+    exposure = RegionNDMap.create(region="icrs;circle(0, 0, 0.1)", axes=[axis_true])
+    exposure.quantity = u.Quantity("1 cm2") * livetime
     bkg_rate = np.ones(30) / u.s
     background.quantity = bkg_rate * livetime
 
@@ -55,12 +59,7 @@ def spectrum_dataset():
     gti = GTI.create(start, stop, reference_time=t_ref)
 
     dataset = SpectrumDataset(
-        models=model,
-        aeff=aeff,
-        livetime=livetime,
-        background=background,
-        name="test",
-        gti=gti,
+        models=models, exposure=exposure, background=background, name=name, gti=gti,
     )
     dataset.fake(random_state=23)
     return dataset
@@ -83,12 +82,12 @@ def test_energy_range(spectrum_dataset):
 def test_info_dict(spectrum_dataset):
     info_dict = spectrum_dataset.info_dict()
 
-    assert_allclose(info_dict["n_on"], 907010)
+    assert_allclose(info_dict["counts"], 907010)
     assert_allclose(info_dict["background"], 3000.0)
 
-    assert_allclose(info_dict["significance"], 2924.522174)
+    assert_allclose(info_dict["sqrt_ts"], 2924.522174)
     assert_allclose(info_dict["excess"], 904010)
-    assert_allclose(info_dict["livetime"].value, 1e2)
+    assert_allclose(info_dict["ontime"].value, 216000)
 
     assert info_dict["name"] == "test"
 
@@ -97,7 +96,7 @@ def test_incorrect_mask(spectrum_dataset):
     mask_fit = np.ones(30, dtype=np.dtype("float"))
     with pytest.raises(ValueError):
         SpectrumDataset(
-            counts=spectrum_dataset.counts.copy(), livetime="1h", mask_fit=mask_fit,
+            counts=spectrum_dataset.counts.copy(), mask_fit=mask_fit,
         )
 
 
@@ -114,10 +113,9 @@ def test_set_model(spectrum_dataset):
 
 
 def test_npred_models():
-    e_reco = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=3).edges
+    e_reco = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=3)
     spectrum_dataset = SpectrumDataset.create(e_reco=e_reco)
-    spectrum_dataset.livetime = 1 * u.h
-    spectrum_dataset.aeff.data.data += 1e10 * u.Unit("cm2")
+    spectrum_dataset.exposure.quantity = 1e10 * u.Unit("cm2 h")
 
     pwl_1 = PowerLawSpectralModel(index=2)
     pwl_2 = PowerLawSpectralModel(index=2)
@@ -125,11 +123,16 @@ def test_npred_models():
     model_2 = SkyModel(spectral_model=pwl_2)
 
     spectrum_dataset.models = Models([model_1, model_2])
-
     npred = spectrum_dataset.npred()
 
     assert_allclose(npred.data.sum(), 64.8)
 
+    npred_sig = spectrum_dataset.npred_signal()
+    assert_allclose(npred_sig.data.sum(), 64.8)
+
+    npred_sig_model1 = spectrum_dataset.npred_signal(model=model_1)
+    assert_allclose(npred_sig_model1.data.sum(), 32.4)
+
 
 @requires_dependency("iminuit")
 def test_fit(spectrum_dataset):
@@ -146,25 +149,27 @@ def test_fit(spectrum_dataset):
 
     pars = result.parameters
     assert_allclose(pars["index"].value, 2.1, rtol=1e-2)
-    assert_allclose(pars["index"].error, 0.00127, rtol=1e-2)
+    assert_allclose(pars["index"].error, 0.001276, rtol=1e-2)
 
     assert_allclose(pars["amplitude"].value, 1e5, rtol=1e-3)
-    assert_allclose(pars["amplitude"].error, 153.450, rtol=1e-2)
+    assert_allclose(pars["amplitude"].error, 153.450825, rtol=1e-2)
 
 
 def test_spectrum_dataset_create():
-    e_reco = u.Quantity([0.1, 1, 10.0], "TeV")
-    e_true = u.Quantity([0.05, 0.5, 5, 20.0], "TeV")
+    e_reco = MapAxis.from_edges(u.Quantity([0.1, 1, 10.0], "TeV"), name="energy")
+    e_true = MapAxis.from_edges(
+        u.Quantity([0.05, 0.5, 5, 20.0], "TeV"), name="energy_true"
+    )
     empty_spectrum_dataset = SpectrumDataset.create(e_reco, e_true, name="test")
 
     assert empty_spectrum_dataset.name == "test"
     assert empty_spectrum_dataset.counts.data.sum() == 0
     assert empty_spectrum_dataset.data_shape[0] == 2
-    assert empty_spectrum_dataset.background.data.sum() == 0
-    assert empty_spectrum_dataset.background.geom.axes[0].nbin == 2
-    assert empty_spectrum_dataset.aeff.data.axis("energy_true").nbin == 3
-    assert empty_spectrum_dataset.edisp.data.axis("energy").nbin == 2
-    assert empty_spectrum_dataset.livetime.value == 0
+    assert empty_spectrum_dataset.npred_background().data.sum() == 0
+    assert empty_spectrum_dataset.npred_background().geom.axes[0].nbin == 2
+    assert empty_spectrum_dataset.exposure.geom.axes[0].nbin == 3
+    assert empty_spectrum_dataset.edisp.edisp_map.geom.axes["energy"].nbin == 2
+    assert empty_spectrum_dataset.gti.time_sum.value == 0
     assert len(empty_spectrum_dataset.gti.table) == 0
     assert empty_spectrum_dataset.energy_range[0] is None
     assert_allclose(empty_spectrum_dataset.mask_safe, 0)
@@ -173,85 +178,128 @@ def test_spectrum_dataset_create():
 def test_spectrum_dataset_stack_diagonal_safe_mask(spectrum_dataset):
     geom = spectrum_dataset.counts.geom
 
-    energy = np.logspace(-1, 1, 31) * u.TeV
-    aeff = EffectiveAreaTable.from_parametrization(energy, "HESS")
-    edisp = EDispKernel.from_diagonal_response(energy, energy)
+    energy = MapAxis.from_energy_bounds("0.1 TeV", "10 TeV", nbin=30)
+    energy_true = MapAxis.from_energy_bounds(
+        "0.1 TeV", "10 TeV", nbin=30, name="energy_true"
+    )
+
+    aeff = EffectiveAreaTable.from_parametrization(energy.edges, "HESS").to_region_map(
+        geom.region
+    )
+
     livetime = 100 * u.s
-    background = spectrum_dataset.background
+    gti = GTI.create(start=0 * u.s, stop=livetime)
+
+    exposure = aeff * livetime
+
+    edisp = EDispKernelMap.from_diagonal_response(
+        energy, energy_true, geom=geom.to_image()
+    )
+    edisp.exposure_map.data = exposure.data[:, :, np.newaxis, :]
+
+    background = spectrum_dataset.npred_background().copy()
+
     spectrum_dataset1 = SpectrumDataset(
+        name="ds1",
         counts=spectrum_dataset.counts.copy(),
-        livetime=livetime,
-        aeff=aeff,
-        edisp=edisp,
-        background=background.copy(),
+        exposure=exposure.copy(),
+        edisp=edisp.copy(),
+        background=background,
+        gti=gti.copy(),
     )
 
     livetime2 = 0.5 * livetime
-    aeff2 = EffectiveAreaTable(energy[:-1], energy[1:], 2 * aeff.data.data)
+    gti2 = GTI.create(start=200 * u.s, stop=200 * u.s + livetime2)
+    aeff2 = aeff * 2
     bkg2 = RegionNDMap.from_geom(geom=geom, data=2 * background.data)
 
     geom = spectrum_dataset.counts.geom
     data = np.ones(spectrum_dataset.data_shape, dtype="bool")
     data[0] = False
     safe_mask2 = RegionNDMap.from_geom(geom=geom, data=data)
+    exposure2 = aeff2 * livetime2
 
+    edisp = edisp.copy()
+    edisp.exposure_map.data = exposure2.data[:, :, np.newaxis, :]
     spectrum_dataset2 = SpectrumDataset(
+        name="ds2",
         counts=spectrum_dataset.counts.copy(),
-        livetime=livetime2,
-        aeff=aeff2,
+        exposure=exposure2,
         edisp=edisp,
         background=bkg2,
         mask_safe=safe_mask2,
+        gti=gti2,
     )
+
     spectrum_dataset1.stack(spectrum_dataset2)
 
     reference = spectrum_dataset.counts.data
     assert_allclose(spectrum_dataset1.counts.data[1:], reference[1:] * 2)
     assert_allclose(spectrum_dataset1.counts.data[0], 141363)
-    assert spectrum_dataset1.livetime == 1.5 * livetime
-    assert_allclose(spectrum_dataset1.background.data[1:], 3 * background.data[1:])
-    assert_allclose(spectrum_dataset1.background.data[0], background.data[0])
+    assert_allclose(spectrum_dataset1.exposure.data[0], 4.755644e09)
     assert_allclose(
-        spectrum_dataset1.aeff.data.data.to_value("m2"),
-        4.0 / 3 * aeff.data.data.to_value("m2"),
+        spectrum_dataset1.npred_background().data[1:], 3 * background.data[1:]
     )
-    assert_allclose(spectrum_dataset1.edisp.pdf_matrix[1:], edisp.pdf_matrix[1:])
-    assert_allclose(spectrum_dataset1.edisp.pdf_matrix[0], 0.5 * edisp.pdf_matrix[0])
+    assert_allclose(spectrum_dataset1.npred_background().data[0], background.data[0])
+
+    assert_allclose(
+        spectrum_dataset1.exposure.quantity.to_value("m2s"),
+        2 * (aeff * livetime).quantity.to_value("m2s"),
+    )
+    kernel = edisp.get_edisp_kernel()
+    kernel_stacked = spectrum_dataset1.edisp.get_edisp_kernel()
+
+    assert_allclose(kernel_stacked.pdf_matrix[1:], kernel.pdf_matrix[1:])
+    assert_allclose(kernel_stacked.pdf_matrix[0], 0.5 * kernel.pdf_matrix[0])
 
 
 def test_spectrum_dataset_stack_nondiagonal_no_bkg(spectrum_dataset):
-    energy = spectrum_dataset.counts.geom.axes[0].edges
+    energy = spectrum_dataset.counts.geom.axes[0]
+    geom = spectrum_dataset.counts.geom.to_image()
 
-    aeff = EffectiveAreaTable.from_parametrization(energy, "HESS")
-    edisp1 = EDispKernel.from_gauss(energy, energy, 0.1, 0)
-    livetime = 100 * u.s
-    spectrum_dataset1 = SpectrumDataset(
-        counts=spectrum_dataset.counts.copy(),
-        livetime=livetime,
-        aeff=aeff,
-        edisp=edisp1,
+    edisp1 = EDispKernelMap.from_gauss(energy, energy, 0.1, 0, geom=geom)
+    edisp1.exposure_map.data += 1
+
+    aeff = EffectiveAreaTable.from_parametrization(energy.edges, "HESS").to_region_map(
+        geom.region
     )
 
-    livetime2 = livetime
-    aeff2 = EffectiveAreaTable(energy[:-1], energy[1:], aeff.data.data)
-    edisp2 = EDispKernel.from_gauss(energy, energy, 0.2, 0.0)
+    geom = spectrum_dataset.counts.geom
+    counts = RegionNDMap.from_geom(geom=geom)
+
+    gti = GTI.create(start=0 * u.s, stop=100 * u.s)
+    spectrum_dataset1 = SpectrumDataset(
+        counts=counts,
+        exposure=aeff * gti.time_sum,
+        edisp=edisp1,
+        meta_table=Table({"OBS_ID": [0]}),
+        gti=gti.copy(),
+    )
+
+    edisp2 = EDispKernelMap.from_gauss(energy, energy, 0.2, 0.0, geom=geom)
+    edisp2.exposure_map.data += 1
+
+    gti2 = GTI.create(start=100 * u.s, stop=200 * u.s)
+
     spectrum_dataset2 = SpectrumDataset(
-        counts=spectrum_dataset.counts.copy(),
-        livetime=livetime2,
-        aeff=aeff2,
+        counts=counts,
+        exposure=aeff * gti2.time_sum,
         edisp=edisp2,
+        meta_table=Table({"OBS_ID": [1]}),
+        gti=gti2,
     )
     spectrum_dataset1.stack(spectrum_dataset2)
 
-    assert spectrum_dataset1.background is None
-    assert spectrum_dataset1.livetime == 2 * livetime
+    assert_allclose(spectrum_dataset1.meta_table["OBS_ID"][0], [0, 1])
+
+    assert spectrum_dataset1.background_model is None
+    assert_allclose(spectrum_dataset1.gti.time_sum.to_value("s"), 200)
     assert_allclose(
-        spectrum_dataset1.aeff.data.data.to_value("m2"), aeff.data.data.to_value("m2")
-    )
-    assert_allclose(spectrum_dataset1.edisp.get_bias(1 * u.TeV), 0.0, atol=1.2e-3)
-    assert_allclose(
-        spectrum_dataset1.edisp.get_resolution(1 * u.TeV), 0.1581, atol=1e-2
+        spectrum_dataset1.exposure.quantity[2].to_value("m2 s"), 1573851.079861
     )
+    kernel = edisp1.get_edisp_kernel()
+    assert_allclose(kernel.get_bias(1 * u.TeV), 0.0, atol=1.2e-3)
+    assert_allclose(kernel.get_resolution(1 * u.TeV), 0.1581, atol=1e-2)
 
 
 @requires_dependency("matplotlib")
@@ -272,13 +320,11 @@ class TestSpectrumOnOff:
 
     def setup(self):
         etrue = np.logspace(-1, 1, 10) * u.TeV
-        self.e_true = etrue
+        self.e_true = MapAxis.from_energy_edges(etrue, name="energy_true")
         ereco = np.logspace(-1, 1, 5) * u.TeV
         elo = ereco[:-1]
         ehi = ereco[1:]
-        self.e_reco = ereco
-        self.aeff = EffectiveAreaTable(etrue[:-1], etrue[1:], np.ones(9) * u.cm ** 2)
-        self.edisp = EDispKernel.from_diagonal_response(etrue, ereco)
+        self.e_reco = MapAxis.from_energy_edges(ereco, name="energy")
 
         start = u.Quantity([0], "s")
         stop = u.Quantity([1000], "s")
@@ -293,12 +339,20 @@ class TestSpectrumOnOff:
         )
         self.wcs = WcsGeom.create(npix=300, binsz=0.01, frame="icrs").wcs
 
+        self.aeff = RegionNDMap.create(
+            region=self.on_region, wcs=self.wcs, axes=[self.e_true], unit="cm2"
+        )
+        self.aeff.data += 1
+
         data = np.ones(elo.shape)
         data[-1] = 0  # to test stats calculation with empty bins
 
         axis = MapAxis.from_edges(ereco, name="energy", interp="log")
         self.on_counts = RegionNDMap.create(
-            region=self.on_region, wcs=self.wcs, axes=[axis]
+            region=self.on_region,
+            wcs=self.wcs,
+            axes=[axis],
+            meta={"EXPOSURE": self.livetime.to_value("s")},
         )
         self.on_counts.data += 1
         self.on_counts.data[-1] = 0
@@ -317,21 +371,29 @@ class TestSpectrumOnOff:
         acceptance_off = RegionNDMap.from_geom(self.off_counts.geom)
         acceptance_off.data += 10
 
+        self.edisp = EDispKernelMap.from_diagonal_response(
+            self.e_reco, self.e_true, self.on_counts.geom.to_image()
+        )
+
+        exposure = self.aeff * self.livetime
+        exposure.meta["livetime"] = self.livetime
+
         self.dataset = SpectrumDatasetOnOff(
             counts=self.on_counts,
             counts_off=self.off_counts,
-            aeff=self.aeff,
+            exposure=exposure,
             edisp=self.edisp,
-            livetime=self.livetime,
             acceptance=acceptance,
             acceptance_off=acceptance_off,
             name="test",
             gti=self.gti,
         )
 
-    def test_spectrumdatasetonoff_create(self):
-        e_reco = u.Quantity([0.1, 1, 10.0], "TeV")
-        e_true = u.Quantity([0.05, 0.5, 5, 20.0], "TeV")
+    def test_spectrum_dataset_on_off_create(self):
+        e_reco = MapAxis.from_edges(u.Quantity([0.1, 1, 10.0], "TeV"), name="energy")
+        e_true = MapAxis.from_edges(
+            u.Quantity([0.05, 0.5, 5, 20.0], "TeV"), name="energy_true"
+        )
         empty_dataset = SpectrumDatasetOnOff.create(e_reco, e_true)
 
         assert empty_dataset.counts.data.sum() == 0
@@ -342,12 +404,13 @@ class TestSpectrumOnOff:
         assert_allclose(empty_dataset.acceptance, 1)
         assert empty_dataset.acceptance.data.shape[0] == 2
         assert empty_dataset.acceptance_off.data.shape[0] == 2
-        assert empty_dataset.livetime.value == 0
+        assert empty_dataset.gti.time_sum.value == 0
         assert len(empty_dataset.gti.table) == 0
         assert empty_dataset.energy_range[0] is None
 
     def test_create_stack(self):
         stacked = SpectrumDatasetOnOff.create(self.e_reco, self.e_true)
+
         stacked.stack(self.dataset)
         assert_allclose(stacked.energy_range.value, self.dataset.energy_range.value)
 
@@ -360,20 +423,29 @@ class TestSpectrumOnOff:
         model = SkyModel(spectral_model=ConstantSpectralModel(const=const))
         livetime = 1 * u.s
 
-        e_reco = self.on_counts.geom.axes[0].edges
-        aeff = EffectiveAreaTable(e_reco[:-1], e_reco[1:], np.ones(4) * u.cm ** 2)
+        aeff = RegionNDMap.create(
+            region=self.on_region,
+            unit="cm2",
+            axes=[self.e_reco.copy(name="energy_true")],
+        )
+
+        aeff.data += 1
         dataset = SpectrumDatasetOnOff(
             counts=self.on_counts,
             counts_off=self.off_counts,
-            aeff=aeff,
+            exposure=aeff * livetime,
             models=model,
-            livetime=livetime,
         )
+        energy = aeff.geom.axes[0].edges
+        expected = aeff.data[0] * (energy[-1] - energy[0]) * const * livetime
 
-        energy = aeff.energy.edges
-        expected = aeff.data.data[0] * (energy[-1] - energy[0]) * const * livetime
+        assert_allclose(dataset.npred_signal().data.sum(), expected.value)
 
-        assert_allclose(dataset.npred_sig().data.sum(), expected.value)
+    def test_to_spectrum_dataset(self):
+        ds = self.dataset.to_spectrum_dataset()
+
+        assert isinstance(ds, SpectrumDataset)
+        assert_allclose(ds.npred_background().data.sum(), 4)
 
     @requires_dependency("matplotlib")
     def test_peek(self):
@@ -391,6 +463,13 @@ class TestSpectrumOnOff:
         with mpl_plot_check():
             dataset.plot_fit()
 
+    @requires_dependency("matplotlib")
+    def test_plot_off_regions(self):
+        from gammapy.visualization import plot_spectrum_datasets_off_regions
+
+        with mpl_plot_check():
+            plot_spectrum_datasets_off_regions([self.dataset])
+
     def test_to_from_ogip_files(self, tmp_path):
         dataset = self.dataset.copy(name="test")
         dataset.to_ogip_files(outdir=tmp_path)
@@ -401,7 +480,7 @@ class TestSpectrumOnOff:
 
         assert_allclose(self.on_counts.data, newdataset.counts.data)
         assert_allclose(self.off_counts.data, newdataset.counts_off.data)
-        assert_allclose(self.edisp.pdf_matrix, newdataset.edisp.pdf_matrix)
+        assert_allclose(self.edisp.edisp_map.data, newdataset.edisp.edisp_map.data)
         assert_time_allclose(newdataset.gti.time_start, dataset.gti.time_start)
 
         assert len(regions) == len(expected_regions)
@@ -413,10 +492,12 @@ class TestSpectrumOnOff:
         mask_safe = RegionNDMap.from_geom(self.on_counts.geom, dtype=bool)
         mask_safe.data += True
 
+        exposure = self.aeff * self.livetime
+        exposure.meta["livetime"] = self.livetime
+
         dataset = SpectrumDatasetOnOff(
             counts=self.on_counts,
-            aeff=self.aeff,
-            livetime=self.livetime,
+            exposure=exposure,
             mask_safe=mask_safe,
             acceptance=1,
             name="test",
@@ -430,15 +511,17 @@ class TestSpectrumOnOff:
         assert newdataset.gti is None
 
     def test_energy_mask(self):
-        mask = self.dataset.counts.geom.energy_mask(emin=0.3 * u.TeV, emax=6 * u.TeV)
+        mask = self.dataset.counts.geom.energy_mask(
+            energy_min=0.3 * u.TeV, energy_max=6 * u.TeV
+        )
         desired = [False, True, True, False]
         assert_allclose(mask[:, 0, 0], desired)
 
-        mask = self.dataset.counts.geom.energy_mask(emax=6 * u.TeV)
+        mask = self.dataset.counts.geom.energy_mask(energy_max=6 * u.TeV)
         desired = [True, True, True, False]
         assert_allclose(mask[:, 0, 0], desired)
 
-        mask = self.dataset.counts.geom.energy_mask(emin=1 * u.TeV)
+        mask = self.dataset.counts.geom.energy_mask(energy_min=1 * u.TeV)
         desired = [False, False, True, True]
         assert_allclose(mask[:, 0, 0], desired)
 
@@ -448,8 +531,7 @@ class TestSpectrumOnOff:
             counts=self.on_counts,
             counts_off=self.off_counts,
             models=model,
-            aeff=self.aeff,
-            livetime=self.livetime,
+            exposure=self.aeff * self.livetime,
             edisp=self.edisp,
             acceptance=1,
             acceptance_off=10,
@@ -461,11 +543,11 @@ class TestSpectrumOnOff:
         """Test the fake dataset"""
         source_model = SkyModel(spectral_model=PowerLawSpectralModel())
         dataset = SpectrumDatasetOnOff(
+            name="test",
             counts=self.on_counts,
             counts_off=self.off_counts,
             models=source_model,
-            aeff=self.aeff,
-            livetime=self.livetime,
+            exposure=self.aeff * self.livetime,
             edisp=self.edisp,
             acceptance=1,
             acceptance_off=10,
@@ -474,7 +556,7 @@ class TestSpectrumOnOff:
 
         background = RegionNDMap.from_geom(dataset.counts.geom)
         background.data += 1
-        dataset.fake(background_model=background, random_state=314)
+        dataset.fake(npred_background=background, random_state=314)
 
         assert real_dataset.counts.data.shape == dataset.counts.data.shape
         assert real_dataset.counts_off.data.shape == dataset.counts_off.data.shape
@@ -484,17 +566,43 @@ class TestSpectrumOnOff:
     def test_info_dict(self):
         info_dict = self.dataset.info_dict()
 
-        assert_allclose(info_dict["n_on"], 3)
-        assert_allclose(info_dict["n_off"], 40)
-        assert_allclose(info_dict["a_on"], 1)
-        assert_allclose(info_dict["a_off"], 10)
+        assert_allclose(info_dict["counts"], 3)
+        assert_allclose(info_dict["counts_off"], 40)
+        assert_allclose(info_dict["acceptance"], 4)
+        assert_allclose(info_dict["acceptance_off"], 40)
 
         assert_allclose(info_dict["alpha"], 0.1)
-        assert_allclose(info_dict["excess"], -1)
-        assert_allclose(info_dict["livetime"].value, 1e3)
+        assert_allclose(info_dict["excess"], -1, rtol=1e-2)
+        assert_allclose(info_dict["ontime"].value, 1e3)
+        assert_allclose(info_dict["sqrt_ts"], -0.501005, rtol=1e-2)
 
         assert info_dict["name"] == "test"
 
+    def test_resample_energy_axis(self):
+        axis = MapAxis.from_edges([0.1, 1, 10] * u.TeV, name="energy", interp="log")
+        grouped = self.dataset.resample_energy_axis(energy_axis=axis)
+
+        assert grouped.counts.data.shape == (2, 1, 1)
+        # exposure should be untouched
+        assert_allclose(grouped.exposure.data, 1000)
+        assert_allclose(np.squeeze(grouped.counts), [2, 1])
+        assert_allclose(np.squeeze(grouped.counts_off), [20, 20])
+        assert grouped.edisp.edisp_map.data.shape == (9, 2, 1, 1)
+        assert_allclose(np.squeeze(grouped.acceptance), [2, 2])
+        assert_allclose(np.squeeze(grouped.acceptance_off), [20, 20])
+
+    def test_to_image(self):
+        grouped = self.dataset.to_image()
+
+        assert grouped.counts.data.shape == (1, 1, 1)
+        # exposure should be untouched
+        assert_allclose(grouped.exposure.data, 1000)
+        assert_allclose(np.squeeze(grouped.counts), 3)
+        assert_allclose(np.squeeze(grouped.counts_off), 40)
+        assert grouped.edisp.edisp_map.data.shape == (9, 1, 1, 1)
+        assert_allclose(np.squeeze(grouped.acceptance), 4)
+        assert_allclose(np.squeeze(grouped.acceptance_off), 40)
+
 
 @requires_data()
 @requires_dependency("iminuit")
@@ -553,8 +661,8 @@ class TestSpectralFit:
         result = self.fit.run()
         pars = result.parameters
 
-        assert_allclose(pars["index"].error, 0.156045, rtol=1e-3)
-        assert_allclose(pars["amplitude"].error, 6.473577e-12, rtol=1e-3)
+        assert_allclose(pars["index"].error, 0.149633, rtol=1e-3)
+        assert_allclose(pars["amplitude"].error, 6.423139e-12, rtol=1e-3)
         pars.to_table()
 
     def test_ecpl_fit(self):
@@ -578,7 +686,7 @@ class TestSpectralFit:
         assert_allclose(actual.value, 5.200e-11, rtol=1e-3)
 
     def test_stats(self):
-        dataset = self.datasets[0]
+        dataset = self.datasets[0].copy()
         dataset.models = self.pwl
 
         fit = Fit([dataset])
@@ -601,14 +709,6 @@ class TestSpectralFit:
     def test_no_edisp(self):
         dataset = self.datasets[0].copy()
 
-        # Bring aeff in RECO space
-        energy = dataset.counts.geom.axes[0].center
-        data = dataset.aeff.data.evaluate(energy_true=energy)
-        e_edges = dataset.counts.geom.axes[0].edges
-
-        dataset.aeff = EffectiveAreaTable(
-            data=data, energy_lo=e_edges[:-1], energy_hi=e_edges[1:]
-        )
         dataset.edisp = None
         dataset.models = self.pwl
 
@@ -656,7 +756,10 @@ def make_observation_list():
     dataoff_2[1] = 0
 
     axis = MapAxis.from_edges(energy, name="energy", interp="log")
+    axis_true = axis.copy(name="energy_true")
+
     geom = RegionGeom(region=None, axes=[axis])
+    geom_true = RegionGeom(region=None, axes=[axis_true])
 
     on_vector = RegionNDMap.from_geom(geom=geom, data=data_on)
     off_vector1 = RegionNDMap.from_geom(geom=geom, data=dataoff_1)
@@ -664,19 +767,23 @@ def make_observation_list():
     mask_safe = RegionNDMap.from_geom(geom, dtype=bool)
     mask_safe.data += True
 
-    aeff = EffectiveAreaTable.from_constant(energy, "1 cm2")
-    edisp = EDispKernel.from_gauss(e_true=energy, e_reco=energy, sigma=0.2, bias=0)
+    aeff = RegionNDMap.from_geom(geom_true, data=1, unit="m2")
+    edisp = EDispKernelMap.from_gauss(
+        energy_axis=axis, energy_axis_true=axis, sigma=0.2, bias=0, geom=geom
+    )
 
     time_ref = Time("2010-01-01")
     gti1 = make_gti({"START": [5, 6, 1, 2], "STOP": [8, 7, 3, 4]}, time_ref=time_ref)
     gti2 = make_gti({"START": [14], "STOP": [15]}, time_ref=time_ref)
 
+    exposure = aeff * livetime
+    exposure.meta["livetime"] = livetime
+
     obs1 = SpectrumDatasetOnOff(
         counts=on_vector,
         counts_off=off_vector1,
-        aeff=aeff,
+        exposure=exposure,
         edisp=edisp,
-        livetime=livetime,
         mask_safe=mask_safe,
         acceptance=1,
         acceptance_off=2,
@@ -686,9 +793,8 @@ def make_observation_list():
     obs2 = SpectrumDatasetOnOff(
         counts=on_vector,
         counts_off=off_vector2,
-        aeff=aeff,
+        exposure=exposure.copy(),
         edisp=edisp,
-        livetime=livetime,
         mask_safe=mask_safe,
         acceptance=1,
         acceptance_off=4,
@@ -707,10 +813,10 @@ class TestSpectrumDatasetOnOffStack:
         # Change threshold to make stuff more interesting
 
         geom = self.datasets[0]._geom
-        data = geom.energy_mask(emin=1.2 * u.TeV, emax=50 * u.TeV)
+        data = geom.energy_mask(energy_min=1.2 * u.TeV, energy_max=50 * u.TeV)
         self.datasets[0].mask_safe = RegionNDMap.from_geom(geom=geom, data=data)
 
-        data = geom.energy_mask(emax=20 * u.TeV)
+        data = geom.energy_mask(energy_max=20 * u.TeV)
         self.datasets[1].mask_safe.data &= data
 
         self.stacked_dataset = self.datasets[0].copy()
@@ -734,32 +840,35 @@ class TestSpectrumDatasetOnOffStack:
         assert summed_off == stacked_off
 
     def test_thresholds(self):
-        e_min, e_max = self.stacked_dataset.energy_range
+        energy_min, energy_max = self.stacked_dataset.energy_range
 
-        assert e_min.unit == "keV"
-        assert_allclose(e_min.value, 8.912509e08, rtol=1e-3)
+        assert energy_min.unit == "keV"
+        assert_allclose(energy_min.value, 8.912509e08, rtol=1e-3)
 
-        assert e_max.unit == "keV"
-        assert_allclose(e_max.value, 4.466836e10, rtol=1e-3)
+        assert energy_max.unit == "keV"
+        assert_allclose(energy_max.value, 4.466836e10, rtol=1e-3)
 
     def test_verify_npred(self):
-        """Veryfing npred is preserved during the stacking"""
+        """Verifying npred is preserved during the stacking"""
         pwl = SkyModel(
             spectral_model=PowerLawSpectralModel(
                 index=2, amplitude=2e-11 * u.Unit("cm-2 s-1 TeV-1"), reference=1 * u.TeV
             )
         )
+
         self.stacked_dataset.models = pwl
 
-        npred_stacked = self.stacked_dataset.npred().data
+        npred_stacked = self.stacked_dataset.npred_signal().data
         npred_stacked[~self.stacked_dataset.mask_safe.data] = 0
         npred_summed = np.zeros_like(npred_stacked)
 
-        for obs in self.datasets:
-            obs.models = pwl
-            npred_summed[obs.mask_safe] += obs.npred().data[obs.mask_safe]
+        for dataset in self.datasets:
+            dataset.models = pwl
+            npred_summed[dataset.mask_safe] += dataset.npred_signal().data[
+                dataset.mask_safe
+            ]
 
-        assert_allclose(npred_stacked, npred_summed)
+        assert_allclose(npred_stacked, npred_summed, rtol=1e-6)
 
     def test_stack_backscal(self):
         """Verify backscal stacking """
@@ -780,45 +889,61 @@ class TestSpectrumDatasetOnOffStack:
 
 @requires_data("gammapy-data")
 def test_datasets_stack_reduce():
+    datasets = Datasets()
     obs_ids = [23523, 23526, 23559, 23592]
-    dataset_list = []
-    for obs in obs_ids:
-        filename = "$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{}.fits"
-        ds = SpectrumDatasetOnOff.from_ogip_files(filename.format(obs))
-        dataset_list.append(ds)
-    datasets = Datasets(dataset_list)
+
+    for obs_id in obs_ids:
+        filename = f"$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{obs_id}.fits"
+        ds = SpectrumDatasetOnOff.from_ogip_files(filename)
+        datasets.append(ds)
+
     stacked = datasets.stack_reduce(name="stacked")
-    assert_allclose(stacked.livetime.to_value("s"), 6313.8116406202325)
+
+    assert_allclose(stacked.exposure.meta["livetime"].to_value("s"), 6313.8116406202325)
 
     info_table = datasets.info_table()
-    assert_allclose(info_table["n_on"], [124, 126, 119, 90])
+    assert_allclose(info_table["counts"], [124, 126, 119, 90])
 
     info_table_cum = datasets.info_table(cumulative=True)
-    assert_allclose(info_table_cum["n_on"], [124, 250, 369, 459])
+    assert_allclose(info_table_cum["counts"], [124, 250, 369, 459])
     assert stacked.name == "stacked"
 
 
+@requires_data("gammapy-data")
+def test_stack_livetime():
+    dataset_ref = SpectrumDatasetOnOff.from_ogip_files(
+        "$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs23523.fits"
+    )
+
+    energy_axis = dataset_ref.counts.geom.axes["energy"]
+    energy_axis_true = dataset_ref.exposure.geom.axes["energy_true"]
+
+    dataset = SpectrumDatasetOnOff.create(e_reco=energy_axis, e_true=energy_axis_true)
+
+    dataset.stack(dataset_ref)
+    assert_allclose(dataset.exposure.meta["livetime"], 1581.736758 * u.s)
+
+    dataset.stack(dataset_ref)
+    assert_allclose(dataset.exposure.meta["livetime"], 2 * 1581.736758 * u.s)
+
+
 def test_spectrum_dataset_on_off_to_yaml(tmpdir):
     spectrum_datasets_on_off = make_observation_list()
     datasets = Datasets(spectrum_datasets_on_off)
-    datasets.write(path=tmpdir)
-    datasets_read = Datasets.read(tmpdir / "_datasets.yaml", tmpdir / "_models.yaml")
+    datasets.write(
+        filename=tmpdir / "datasets.yaml", filename_models=tmpdir / "models.yaml"
+    )
+
+    datasets_read = Datasets.read(
+        filename=tmpdir / "datasets.yaml", filename_models=tmpdir / "models.yaml"
+    )
+
     assert len(datasets_read) == len(datasets)
     assert datasets_read[0].name == datasets[0].name
     assert datasets_read[1].name == datasets[1].name
     assert datasets_read[1].counts.data.sum() == datasets[1].counts.data.sum()
 
 
-def test_stack_no_livetime():
-    e_reco = np.logspace(0, 1, 3) * u.TeV
-    dataset_1 = SpectrumDataset.create(e_reco=e_reco)
-    dataset_1.livetime = None
-    dataset_2 = dataset_1.copy()
-
-    with pytest.raises(ValueError):
-        dataset_1.stack(dataset_2)
-
-
 @requires_dependency("iminuit")
 class TestFit:
     """Test fit on counts spectra without any IRFs"""
@@ -845,8 +970,10 @@ class TestFit:
 
         self.src = RegionNDMap.from_geom(geom=geom, data=source_counts)
 
-        self.src.livetime = 1 * u.s
-        self.aeff = EffectiveAreaTable.from_constant(energy, "1 cm2")
+        self.livetime = 1 * u.s
+        self.aeff = EffectiveAreaTable.from_constant(energy, "1 cm2").to_region_map(
+            region=None
+        )
 
         npred_bkg = bkg_model.integral(energy[:-1], energy[1:]).value
 
@@ -860,8 +987,7 @@ class TestFit:
         dataset = SpectrumDataset(
             models=self.source_model,
             counts=self.src,
-            aeff=self.aeff,
-            livetime=self.src.livetime,
+            exposure=self.aeff * self.livetime,
         )
 
         npred = dataset.npred().data
@@ -887,8 +1013,7 @@ class TestFit:
         dataset = SpectrumDatasetOnOff(
             counts=on_vector,
             counts_off=self.off,
-            aeff=self.aeff,
-            livetime=self.src.livetime,
+            exposure=self.aeff * self.livetime,
             acceptance=1,
             acceptance_off=1 / self.alpha,
         )
@@ -913,10 +1038,10 @@ class TestFit:
         dataset = SpectrumDatasetOnOff(counts=self.src, mask_safe=mask_safe)
 
         assert np.sum(dataset.mask_safe) == self.nbins
-        e_min, e_max = dataset.energy_range
+        energy_min, energy_max = dataset.energy_range
 
-        assert_allclose(e_max.value, 10)
-        assert_allclose(e_min.value, 0.1)
+        assert_allclose(energy_max.value, 10)
+        assert_allclose(energy_min.value, 0.1)
 
     def test_stat_profile(self):
         geom = self.src.geom
@@ -925,8 +1050,7 @@ class TestFit:
 
         dataset = SpectrumDataset(
             models=self.source_model,
-            aeff=self.aeff,
-            livetime=self.src.livetime,
+            exposure=self.aeff * self.livetime,
             counts=self.src,
             mask_safe=mask_safe,
         )
@@ -935,5 +1059,5 @@ class TestFit:
         true_idx = result.parameters["index"].value
         values = np.linspace(0.95 * true_idx, 1.05 * true_idx, 100)
         profile = fit.stat_profile("index", values=values)
-        actual = values[np.argmin(profile["stat"])]
+        actual = values[np.argmin(profile["stat_scan"])]
         assert_allclose(actual, true_idx, rtol=0.01)
