@@ -1,13 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import logging
 import numpy as np
+from astropy import units as u
 from astropy.convolution import Gaussian2DKernel
 from astropy.coordinates import Angle
 from astropy.io import fits
 from astropy.stats import gaussian_fwhm_to_sigma
 from astropy.table import Table
-from astropy.units import Quantity, Unit
-from gammapy.maps import MapAxis
+from gammapy.maps import MapAxes, MapAxis
 from gammapy.utils.array import array_stats_str
 from gammapy.utils.gauss import MultiGauss2D
 from gammapy.utils.interpolation import ScaledRegularGridInterpolator
@@ -21,19 +21,16 @@ log = logging.getLogger(__name__)
 
 
 class EnergyDependentMultiGaussPSF:
-    """
-    Triple Gauss analytical PSF depending on energy and theta.
+    """Triple Gauss analytical PSF depending on energy and theta.
 
     To evaluate the PSF call the ``to_energy_dependent_table_psf`` or ``psf_at_energy_and_theta`` methods.
 
     Parameters
     ----------
-    energy_lo : `~astropy.units.Quantity`
-        Lower energy boundary of the energy bin.
-    energy_hi : `~astropy.units.Quantity`
-        Upper energy boundary of the energy bin.
-    theta : `~astropy.units.Quantity`
-        Center values of the theta bins.
+    energy_axis_true : `MapAxis`
+        True energy axis
+    offset_axis : `MapAxis`
+        Offset axis.
     sigmas : list of 'numpy.ndarray'
         Triple Gauss sigma parameters, where every entry is
         a two dimensional 'numpy.ndarray' containing the sigma
@@ -43,9 +40,9 @@ class EnergyDependentMultiGaussPSF:
         a two dimensional 'numpy.ndarray' containing the norm
         value for every given energy and theta. Norm corresponds
         to the value of the Gaussian at theta = 0.
-    energy_thresh_lo : `~astropy.units.Quantity`
+    energy_thresh_lo : `~astropy.units.u.Quantity`
         Lower save energy threshold of the psf.
-    energy_thresh_hi : `~astropy.units.Quantity`
+    energy_thresh_hi : `~astropy.units.u.Quantity`
         Upper save energy threshold of the psf.
 
     Examples
@@ -59,41 +56,53 @@ class EnergyDependentMultiGaussPSF:
         from gammapy.irf import EnergyDependentMultiGaussPSF
         filename = '$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits'
         psf = EnergyDependentMultiGaussPSF.read(filename, hdu='POINT SPREAD FUNCTION')
-        psf.plot_containment(0.68, show_safe_energy=False)
+        psf.plot_containment(0.68)
         plt.show()
     """
 
+    tag = "psf_3gauss"
+
     def __init__(
         self,
-        energy_lo,
-        energy_hi,
-        theta,
+        energy_axis_true,
+        offset_axis,
         sigmas,
         norms,
         energy_thresh_lo="0.1 TeV",
         energy_thresh_hi="100 TeV",
     ):
-        self.energy_lo = Quantity(energy_lo, "TeV")
-        self.energy_hi = Quantity(energy_hi, "TeV")
-        self.energy = np.sqrt(self.energy_hi * self.energy_lo)
-        self.theta = Quantity(theta, "deg")
+        assert energy_axis_true.name == "energy_true"
+        assert offset_axis.name == "offset"
+
+        self._energy_axis_true = energy_axis_true
+        self._offset_axis = offset_axis
+
         sigmas[0][sigmas[0] == 0] = 1
         sigmas[1][sigmas[1] == 0] = 1
         sigmas[2][sigmas[2] == 0] = 1
         self.sigmas = sigmas
 
         self.norms = norms
-        self.energy_thresh_lo = Quantity(energy_thresh_lo, "TeV")
-        self.energy_thresh_hi = Quantity(energy_thresh_hi, "TeV")
+        self.energy_thresh_lo = u.Quantity(energy_thresh_lo, "TeV")
+        self.energy_thresh_hi = u.Quantity(energy_thresh_hi, "TeV")
 
         self._interp_norms = self._setup_interpolators(self.norms)
         self._interp_sigmas = self._setup_interpolators(self.sigmas)
 
+    @property
+    def energy_axis_true(self):
+        return self._energy_axis_true
+
+    @property
+    def offset_axis(self):
+        return self._offset_axis
+
     def _setup_interpolators(self, values_list):
         interps = []
         for values in values_list:
             interp = ScaledRegularGridInterpolator(
-                points=(self.theta, self.energy), values=values
+                points=(self.offset_axis.center, self.energy_axis_true.center),
+                values=values,
             )
             interps.append(interp)
         return interps
@@ -107,11 +116,11 @@ class EnergyDependentMultiGaussPSF:
         filename : str
             File name
         """
-        with fits.open(make_path(filename), memmap=False) as hdulist:
-            return cls.from_fits(hdulist[hdu])
+        with fits.open(str(make_path(filename)), memmap=False) as hdulist:
+            return cls.from_table_hdu(hdulist[hdu])
 
     @classmethod
-    def from_fits(cls, hdu):
+    def from_table_hdu(cls, hdu):
         """Create `EnergyDependentMultiGaussPSF` from HDU list.
 
         Parameters
@@ -119,12 +128,17 @@ class EnergyDependentMultiGaussPSF:
         hdu : `~astropy.io.fits.BinTableHDU`
             HDU
         """
-        energy_lo = Quantity(hdu.data["ENERG_LO"][0], "TeV")
-        energy_hi = Quantity(hdu.data["ENERG_HI"][0], "TeV")
-        theta = Angle(hdu.data["THETA_LO"][0], "deg")
+        table = Table.read(hdu)
+
+        energy_axis_true = MapAxis.from_table(
+            table, column_prefix="ENERG", format="gadf-dl3"
+        )
+        offset_axis = MapAxis.from_table(
+            table, column_prefix="THETA", format="gadf-dl3"
+        )
 
         # Get sigmas
-        shape = (len(theta), len(energy_hi))
+        shape = (offset_axis.nbin, energy_axis_true.nbin)
         sigmas = []
         for key in ["SIGMA_1", "SIGMA_2", "SIGMA_3"]:
             sigma = hdu.data[key].reshape(shape).copy()
@@ -138,14 +152,20 @@ class EnergyDependentMultiGaussPSF:
 
         opts = {}
         try:
-            opts["energy_thresh_lo"] = Quantity(hdu.header["LO_THRES"], "TeV")
-            opts["energy_thresh_hi"] = Quantity(hdu.header["HI_THRES"], "TeV")
+            opts["energy_thresh_lo"] = u.Quantity(hdu.header["LO_THRES"], "TeV")
+            opts["energy_thresh_hi"] = u.Quantity(hdu.header["HI_THRES"], "TeV")
         except KeyError:
             pass
 
-        return cls(energy_lo, energy_hi, theta, sigmas, norms, **opts)
+        return cls(
+            energy_axis_true=energy_axis_true,
+            offset_axis=offset_axis,
+            sigmas=sigmas,
+            norms=norms,
+            **opts,
+        )
 
-    def to_fits(self):
+    def to_hdulist(self):
         """
         Convert psf table data to FITS hdu list.
 
@@ -156,10 +176,6 @@ class EnergyDependentMultiGaussPSF:
         """
         # Set up data
         names = [
-            "ENERG_LO",
-            "ENERG_HI",
-            "THETA_LO",
-            "THETA_HI",
             "SCALE",
             "SIGMA_1",
             "AMPL_2",
@@ -167,13 +183,9 @@ class EnergyDependentMultiGaussPSF:
             "AMPL_3",
             "SIGMA_3",
         ]
-        units = ["TeV", "TeV", "deg", "deg", "", "deg", "", "deg", "", "deg"]
+        units = ["", "deg", "", "deg", "", "deg"]
 
         data = [
-            self.energy_lo,
-            self.energy_hi,
-            self.theta,
-            self.theta,
             self.norms[0],
             self.sigmas[0],
             self.norms[1],
@@ -182,7 +194,9 @@ class EnergyDependentMultiGaussPSF:
             self.sigmas[2],
         ]
 
-        table = Table()
+        axes = MapAxes([self.energy_axis_true, self.offset_axis])
+        table = axes.to_table(format="gadf-dl3")
+
         for name_, data_, unit_ in zip(names, data, units):
             table[name_] = [data_]
             table[name_].unit = unit_
@@ -199,7 +213,7 @@ class EnergyDependentMultiGaussPSF:
 
         Calls `~astropy.io.fits.HDUList.writeto`, forwarding all arguments.
         """
-        self.to_fits().writeto(filename, *args, **kwargs)
+        self.to_hdulist().writeto(str(make_path(filename)), *args, **kwargs)
 
     def psf_at_energy_and_theta(self, energy, theta):
         """
@@ -209,7 +223,7 @@ class EnergyDependentMultiGaussPSF:
 
         Parameters
         ----------
-        energy : `~astropy.units.Quantity`
+        energy : `~astropy.units.u.Quantity`
             Energy at which a PSF is requested.
         theta : `~astropy.coordinates.Angle`
             Offset angle at which a PSF is requested.
@@ -219,8 +233,8 @@ class EnergyDependentMultiGaussPSF:
         psf : `~gammapy.morphology.MultiGauss2D`
             Multigauss PSF object.
         """
-        energy = Quantity(energy)
-        theta = Quantity(theta)
+        energy = u.Quantity(energy)
+        theta = u.Quantity(theta)
 
         pars = {}
         for name, interp_norm in zip(["scale", "A_2", "A_3"], self._interp_norms):
@@ -236,7 +250,7 @@ class EnergyDependentMultiGaussPSF:
         """Compute containment for all energy and theta values"""
         # This is a false positive from pylint
         # See https://github.com/PyCQA/pylint/issues/2435
-        energies = Quantity(
+        energies = u.Quantity(
             energy
         ).flatten()  # pylint:disable=assignment-from-no-return
         thetas = Angle(theta).flatten()
@@ -254,12 +268,9 @@ class EnergyDependentMultiGaussPSF:
                     )
                     log.debug(f"Sigmas: {psf.sigmas} Norms: {psf.norms}")
                     radius[jdx, idx] = np.nan
-
         return Angle(radius, "deg")
 
-    def plot_containment(
-        self, fraction=0.68, ax=None, show_safe_energy=False, add_cbar=True, **kwargs
-    ):
+    def plot_containment(self, fraction=0.68, ax=None, add_cbar=True, **kwargs):
         """
         Plot containment image with energy and theta axes.
 
@@ -274,8 +285,8 @@ class EnergyDependentMultiGaussPSF:
 
         ax = plt.gca() if ax is None else ax
 
-        energy = self.energy_hi
-        offset = self.theta
+        energy = self.energy_axis_true.center
+        offset = self.offset_axis.center
 
         # Set up and compute data
         containment = self.containment_radius(energy, offset, fraction)
@@ -297,8 +308,7 @@ class EnergyDependentMultiGaussPSF:
         ax.set_xlim(x.min(), x.max())
         ax.set_ylim(y.min(), y.max())
 
-        if show_safe_energy:
-            self._plot_safe_energy_range(ax)
+        self._plot_safe_energy_range(ax)
 
         if add_cbar:
             label = f"Containment radius R{100 * fraction:.0f} ({containment.unit})"
@@ -309,11 +319,11 @@ class EnergyDependentMultiGaussPSF:
     def _plot_safe_energy_range(self, ax):
         """add safe energy range lines to the plot"""
         esafe = self.energy_thresh_lo
-        omin = self.offset.value.min()
-        omax = self.offset.value.max()
-        ax.hlines(y=esafe.value, xmin=omin, xmax=omax)
+        omin = self.offset_axis.center.min()
+        omax = self.offset_axis.center.max()
+        ax.vlines(x=esafe.value, ymin=omin.value, ymax=omax.value)
         label = f"Safe energy threshold: {esafe:3.2f}"
-        ax.text(x=0.1, y=0.9 * esafe.value, s=label, va="top")
+        ax.text(x=1.1 * esafe.value, y=0.3, s=label, va="top")
 
     def plot_containment_vs_energy(
         self, fractions=[0.68, 0.95], thetas=Angle([0, 1], "deg"), ax=None, **kwargs
@@ -324,15 +334,13 @@ class EnergyDependentMultiGaussPSF:
 
         ax = plt.gca() if ax is None else ax
 
-        energy = MapAxis.from_energy_bounds(
-            self.energy_lo[0], self.energy_hi[-1], 100
-        ).edges
+        energy = self.energy_axis_true.center
 
         for theta in thetas:
             for fraction in fractions:
                 radius = self.containment_radius(energy, theta, fraction).squeeze()
-                label = f"{theta.deg} deg, {100 * fraction:.1f}%"
-                ax.plot(energy.value, radius.value, label=label)
+                kwargs.setdefault("label", f"{theta.deg} deg, {100 * fraction:.1f}%")
+                ax.plot(energy.value, radius.value, **kwargs)
 
         ax.semilogx()
         ax.legend(loc="best")
@@ -358,8 +366,8 @@ class EnergyDependentMultiGaussPSF:
     def info(
         self,
         fractions=[0.68, 0.95],
-        energies=Quantity([1.0, 10.0], "TeV"),
-        thetas=Quantity([0.0], "deg"),
+        energies=u.Quantity([1.0, 10.0], "TeV"),
+        thetas=u.Quantity([0.0], "deg"),
     ):
         """
         Print PSF summary info.
@@ -371,9 +379,9 @@ class EnergyDependentMultiGaussPSF:
         ----------
         fractions : list
             Containment fraction to compute containment radius for.
-        energies : `~astropy.units.Quantity`
+        energies : `~astropy.units.u.Quantity`
             Energies to compute containment radius for.
-        thetas : `~astropy.units.Quantity`
+        thetas : `~astropy.units.u.Quantity`
             Thetas to compute containment radius for.
 
         Returns
@@ -383,9 +391,9 @@ class EnergyDependentMultiGaussPSF:
         """
         ss = "\nSummary PSF info\n"
         ss += "----------------\n"
-        ss += array_stats_str(self.theta.to("deg"), "Theta")
-        ss += array_stats_str(self.energy_hi, "Energy hi")
-        ss += array_stats_str(self.energy_lo, "Energy lo")
+        ss += array_stats_str(self.offset_axis.center.to("deg"), "Theta")
+        ss += array_stats_str(self.energy_axis_true.edges[1:], "Energy hi")
+        ss += array_stats_str(self.energy_axis_true.edges[:-1], "Energy lo")
         ss += f"Safe energy threshold lo: {self.energy_thresh_lo:6.3f}\n"
         ss += f"Safe energy threshold hi: {self.energy_thresh_hi:6.3f}\n"
 
@@ -402,8 +410,7 @@ class EnergyDependentMultiGaussPSF:
         return ss
 
     def to_energy_dependent_table_psf(self, theta=None, rad=None, exposure=None):
-        """
-        Convert triple Gaussian PSF ot table PSF.
+        """Convert triple Gaussian PSF ot table PSF.
 
         Parameters
         ----------
@@ -412,7 +419,7 @@ class EnergyDependentMultiGaussPSF:
         rad : `~astropy.coordinates.Angle`
             Offset from PSF center used for evaluating the PSF on a grid.
             Default offset = [0, 0.005, ..., 1.495, 1.5] deg.
-        exposure : `~astropy.units.Quantity`
+        exposure : `~astropy.units.u.Quantity`
             Energy dependent exposure. Should be in units equivalent to 'cm^2 s'.
             Default exposure = 1.
 
@@ -422,7 +429,7 @@ class EnergyDependentMultiGaussPSF:
             Instance of `EnergyDependentTablePSF`.
         """
         # Convert energies to log center
-        energies = self.energy
+        energies = self.energy_axis_true.center
         # Defaults and input handling
         if theta is None:
             theta = Angle(0, "deg")
@@ -431,17 +438,20 @@ class EnergyDependentMultiGaussPSF:
 
         if rad is None:
             rad = Angle(np.arange(0, 1.5, 0.005), "deg")
-        else:
-            rad = Angle(rad).to("deg")
 
-        psf_value = Quantity(np.zeros((energies.size, rad.size)), "deg^-2")
+        rad_axis = MapAxis.from_nodes(rad, name="rad")
+
+        psf_value = u.Quantity(np.zeros((energies.size, rad.size)), "deg^-2")
 
         for idx, energy in enumerate(energies):
             psf_gauss = self.psf_at_energy_and_theta(energy, theta)
-            psf_value[idx] = Quantity(psf_gauss(rad), "deg^-2")
+            psf_value[idx] = u.Quantity(psf_gauss(rad), "deg^-2")
 
         return EnergyDependentTablePSF(
-            energy=energies, rad=rad, exposure=exposure, psf_value=psf_value
+            energy_axis_true=self.energy_axis_true,
+            rad_axis=rad_axis,
+            exposure=exposure,
+            psf_value=psf_value,
         )
 
     def to_psf3d(self, rad=None):
@@ -449,7 +459,7 @@ class EnergyDependentMultiGaussPSF:
 
         Parameters
         ----------
-        rad : `~astropy.units.Quantity` or `~astropy.coordinates.Angle`
+        rad : `~astropy.units.u.Quantity` or `~astropy.coordinates.Angle`
             the array of position errors (rad) on which the PSF3D will be defined
 
         Returns
@@ -457,34 +467,28 @@ class EnergyDependentMultiGaussPSF:
         psf3d : `~gammapy.irf.PSF3D`
             the PSF3D. It will be defined on the same energy and offset values than the input psf.
         """
-        offsets = self.theta
-        energy = self.energy
-        energy_lo = self.energy_lo
-        energy_hi = self.energy_hi
+        offsets = self.offset_axis.center
+        energy = self.energy_axis_true.center
+
         if rad is None:
-            rad = np.linspace(0, 0.66, 67) * Unit(
-                "deg"
-            )  # Arbitrary binning of 0.01 in rad
-        rad_lo = rad[:-1]
-        rad_hi = rad[1:]
+            rad = np.linspace(0, 0.66, 67) * u.deg
 
-        psf_values = np.zeros(
-            (rad_lo.shape[0], offsets.shape[0], energy_lo.shape[0])
-        ) * Unit("sr-1")
+        rad_axis = MapAxis.from_edges(rad, name="rad")
 
-        for i, offset in enumerate(offsets):
-            psftable = self.to_energy_dependent_table_psf(offset)
-            psf_values[:, i, :] = psftable.evaluate(energy, 0.5 * (rad_lo + rad_hi)).T
+        shape = (self.energy_axis_true.nbin, self.offset_axis.nbin, rad_axis.nbin)
+        psf_value = np.zeros(shape) * u.Unit("sr-1")
+
+        for idx, offset in enumerate(offsets):
+            table_psf = self.to_energy_dependent_table_psf(offset)
+            psf_value[:, idx, :] = table_psf.evaluate(energy, rad_axis.center)
 
         return PSF3D(
-            energy_lo,
-            energy_hi,
-            offsets,
-            rad_lo,
-            rad_hi,
-            psf_values,
-            self.energy_thresh_lo,
-            self.energy_thresh_hi,
+            energy_axis_true=self.energy_axis_true,
+            rad_axis=rad_axis,
+            offset_axis=self.offset_axis,
+            psf_value=psf_value,
+            energy_thresh_lo=self.energy_thresh_lo,
+            energy_thresh_hi=self.energy_thresh_hi,
         )
 
 
