@@ -15,8 +15,8 @@ class TestEDispKernel:
         self.resolution = 0.1
         self.bias = 0
         self.edisp = EDispKernel.from_gauss(
-            e_true=self.e_true,
-            e_reco=self.e_reco,
+            energy_true=self.e_true,
+            energy=self.e_reco,
             pdf_threshold=1e-7,
             sigma=self.resolution,
             bias=self.bias,
@@ -35,12 +35,28 @@ class TestEDispKernel:
 
         # Test square matrix
         edisp = EDispKernel.from_diagonal_response(e_true)
-        assert_allclose(edisp.e_reco.edges.value, e_true.value)
-        assert edisp.e_reco.unit == "TeV"
+        assert_allclose(edisp.energy_axis.edges.value, e_true.value)
+        assert edisp.energy_axis.unit == "TeV"
         assert_equal(edisp.pdf_matrix[0][0], 1)
         assert_equal(edisp.pdf_matrix[2][0], 0)
         assert edisp.pdf_matrix.sum() == 4
 
+    def test_to_image(self):
+        e_reco = MapAxis.from_energy_bounds("0.1 TeV", "10 TeV", nbin=3)
+        e_true = MapAxis.from_energy_bounds(
+            "0.08 TeV", "20 TeV", nbin=5, name="energy_true"
+        )
+        edisp = EDispKernel.from_gauss(
+            energy=e_reco.edges, energy_true=e_true.edges, sigma=0.2, bias=0.1
+        )
+        im = edisp.to_image()
+
+        assert im.pdf_matrix.shape == (5, 1)
+        assert_allclose(
+            im.pdf_matrix, [[0.97142], [1.0], [1.0], [1.0], [0.12349]], rtol=1e-3
+        )
+        assert_allclose(im.energy_axis.edges, [0.1, 10] * u.TeV)
+
     def test_str(self):
         assert "EDispKernel" in str(self.edisp)
 
@@ -114,14 +130,14 @@ class TestEnergyDispersion2D:
         # Check evaluation at all nodes
         actual = self.edisp.data.evaluate().shape
         desired = (
-            self.edisp.data.axis("energy_true").nbin,
-            self.edisp.data.axis("migra").nbin,
-            self.edisp.data.axis("offset").nbin,
+            self.edisp.data.axes["energy_true"].nbin,
+            self.edisp.data.axes["migra"].nbin,
+            self.edisp.data.axes["offset"].nbin,
         )
         assert_equal(actual, desired)
 
     def test_get_response(self):
-        pdf = self.edisp2.get_response(offset=0.7 * u.deg, e_true=1 * u.TeV)
+        pdf = self.edisp2.get_response(offset=0.7 * u.deg, energy_true=1 * u.TeV)
         assert_allclose(pdf.sum(), 1)
         assert_allclose(pdf.max(), 0.010421, rtol=1e-4)
 
@@ -130,7 +146,7 @@ class TestEnergyDispersion2D:
         offset = Angle(0.612, "deg")
         e_reco = MapAxis.from_energy_bounds(1, 10, 7, "TeV").edges
         e_true = MapAxis.from_energy_bounds(0.8, 5, 5, "TeV").edges
-        rmf = self.edisp.to_energy_dispersion(offset, e_true=e_true, e_reco=e_reco)
+        rmf = self.edisp.to_edisp_kernel(offset, energy_true=e_true, energy=e_reco)
         assert_allclose(rmf.data.data[2, 3], 0.08, atol=5e-2)  # same tolerance as above
         actual = rmf.pdf_matrix[2]
         e_val = np.sqrt(e_true[2] * e_true[3])
@@ -138,31 +154,31 @@ class TestEnergyDispersion2D:
         assert_equal(actual, desired)
 
     def test_write(self):
-        energy_lo = np.logspace(0, 1, 11)[:-1] * u.TeV
-        energy_hi = np.logspace(0, 1, 11)[1:] * u.TeV
-        offset_lo = np.linspace(0, 1, 4)[:-1] * u.deg
-        offset_hi = np.linspace(0, 1, 4)[1:] * u.deg
-        migra_lo = np.linspace(0, 3, 4)[:-1]
-        migra_hi = np.linspace(0, 3, 4)[1:]
-
-        data = (
-            np.ones(shape=(len(energy_lo), len(migra_lo), len(offset_lo))) * u.cm * u.cm
+        energy_axis_true = MapAxis.from_energy_bounds(
+            "1 TeV", "10 TeV", nbin=10, name="energy_true"
         )
 
+        offset_axis = MapAxis.from_bounds(
+            0, 1, nbin=3, unit="deg", name="offset", node_type="edges"
+        )
+
+        migra_axis = MapAxis.from_bounds(0, 3, nbin=3, name="migra", node_type="edges")
+
+        shape = (energy_axis_true.nbin, migra_axis.nbin, offset_axis.nbin)
+
+        data = np.ones(shape=shape) * u.cm ** 2
+
         edisp = EnergyDispersion2D(
-            e_true_lo=energy_lo,
-            e_true_hi=energy_hi,
-            migra_lo=migra_lo,
-            migra_hi=migra_hi,
-            offset_lo=offset_lo,
-            offset_hi=offset_hi,
+            energy_axis_true=energy_axis_true,
+            migra_axis=migra_axis,
+            offset_axis=offset_axis,
             data=data,
         )
 
-        hdu = edisp.to_fits()
-        energy = edisp.data.axis("energy_true").edges
+        hdu = edisp.to_table_hdu()
+        energy = edisp.data.axes["energy_true"].edges
         assert_equal(hdu.data["ENERG_LO"][0], energy[:-1].value)
-        assert hdu.header["TUNIT1"] == edisp.data.axis("energy_true").unit
+        assert hdu.header["TUNIT1"] == edisp.data.axes["energy_true"].unit
 
     @requires_dependency("matplotlib")
     def test_plot_migration(self):
