@@ -10,7 +10,7 @@ from gammapy.irf.psf_gauss import (
     HESSMultiGaussPSF,
     multi_gauss_psf_kernel,
 )
-from gammapy.utils.testing import requires_data
+from gammapy.utils.testing import mpl_plot_check, requires_data, requires_dependency
 
 
 @requires_data()
@@ -51,8 +51,8 @@ class TestEnergyDependentMultiGaussPSF:
     def test_to_psf3d(self, psf):
         rads = np.linspace(0.0, 1.0, 101) * u.deg
         psf_3d = psf.to_psf3d(rads)
-        assert psf_3d.rad_lo.shape == (100,)
-        assert psf_3d.rad_lo.unit == "deg"
+        assert psf_3d.rad_axis.nbin == 100
+        assert psf_3d.rad_axis.unit == "deg"
 
         theta = 0.5 * u.deg
         energy = 0.5 * u.TeV
@@ -66,6 +66,11 @@ class TestEnergyDependentMultiGaussPSF:
         )
         assert_allclose(np.squeeze(desired), actual, atol=0.005)
 
+    @requires_dependency("matplotlib")
+    def test_peek(self, psf):
+        with mpl_plot_check():
+            psf.peek()
+
 
 @requires_data()
 def test_psf_cta_1dc():
@@ -84,7 +89,7 @@ def test_psf_cta_1dc():
     # Check that evaluation works for an energy / offset where an energy is available
     psf = psf_irf.to_energy_dependent_table_psf("2 deg")
     psf = psf.table_psf_at_energy("1 TeV")
-    assert_allclose(psf.containment_radius(0.68).deg, 0.053838, atol=1e-4)
+    assert_allclose(psf.containment_radius(0.68).deg, 0.052841, atol=1e-4)
 
 
 class TestHESS:
