@@ -43,9 +43,14 @@ def test_psf_king_to_table(psf_king):
     assert_quantity_allclose(psf_king_table_off2.psf_value[8, 200], value_off2)
 
     # Test that the integral value is close to one
-    bin_off = psf_king_table_off1.rad[1] - psf_king_table_off1.rad[0]
+    bin_off = psf_king_table_off1.rad_axis.bin_width[0]
+
     integral = np.sum(
-        psf_king_table_off1.psf_value[8] * 2 * np.pi * psf_king_table_off1.rad * bin_off
+        psf_king_table_off1.psf_value[8]
+        * 2
+        * np.pi
+        * psf_king_table_off1.rad_axis.center
+        * bin_off
     )
     assert_quantity_allclose(integral, 1, atol=0.03)
 
@@ -55,7 +60,9 @@ def test_psf_king_write(psf_king, tmp_path):
     psf_king.write(tmp_path / "tmp.fits")
     psf_king2 = PSFKing.read(tmp_path / "tmp.fits")
 
-    assert_quantity_allclose(psf_king2.energy, psf_king.energy)
-    assert_quantity_allclose(psf_king2.offset, psf_king.offset)
+    assert_quantity_allclose(
+        psf_king2.energy_axis_true.edges, psf_king.energy_axis_true.edges
+    )
+    assert_quantity_allclose(psf_king2.offset_axis.center, psf_king.offset_axis.center)
     assert_quantity_allclose(psf_king2.gamma, psf_king.gamma)
     assert_quantity_allclose(psf_king2.sigma, psf_king.sigma)
