@@ -1,10 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import logging
+import astropy.units as u
+from astropy.table import Table
 from gammapy.datasets import MapDataset
-from gammapy.irf import EnergyDependentMultiGaussPSF
+from gammapy.irf import EDispKernelMap, EnergyDependentMultiGaussPSF, PSFMap
 from gammapy.maps import Map
-from gammapy.modeling.models import BackgroundModel
+from .core import Maker
 from .utils import (
+    make_edisp_kernel_map,
     make_edisp_map,
     make_map_background_irf,
     make_map_exposure_true_energy,
@@ -16,22 +19,23 @@ __all__ = ["MapDatasetMaker"]
 log = logging.getLogger(__name__)
 
 
-class MapDatasetMaker:
+class MapDatasetMaker(Maker):
     """Make maps for a single IACT observation.
 
     Parameters
     ----------
-    background_oversampling : int
-        Background evaluation oversampling factor in energy.
     selection : list
         List of str, selecting which maps to make.
         Available: 'counts', 'exposure', 'background', 'psf', 'edisp'
         By default, all maps are made.
+    background_oversampling : int
+        Background evaluation oversampling factor in energy.
     """
 
+    tag = "MapDatasetMaker"
     available_selection = ["counts", "exposure", "background", "psf", "edisp"]
 
-    def __init__(self, background_oversampling=None, selection=None):
+    def __init__(self, selection=None, background_oversampling=None):
         self.background_oversampling = background_oversampling
 
         if selection is None:
@@ -81,6 +85,8 @@ class MapDatasetMaker:
         exposure : `~gammapy.maps.Map`
             Exposure map.
         """
+        if isinstance(observation.aeff, Map):
+            return observation.aeff.interp_to_geom(geom=geom,)
         return make_map_exposure_true_energy(
             pointing=observation.pointing_radec,
             livetime=observation.observation_live_time_duration,
@@ -126,6 +132,8 @@ class MapDatasetMaker:
         background : `~gammapy.maps.Map`
             Background map.
         """
+        if isinstance(observation.bkg, Map):
+            return observation.bkg.interp_to_geom(geom=geom, preserve_counts=True)
         bkg_coordsys = observation.bkg.meta.get("FOVALIGN", "RADEC")
 
         if bkg_coordsys == "ALTAZ":
@@ -158,10 +166,10 @@ class MapDatasetMaker:
 
         Returns
         -------
-        edisp : `~gammapy.cube.EDispMap`
+        edisp : `~gammapy.irf.EDispMap`
             Edisp map.
         """
-        exposure = self.make_exposure_irf(geom.squash(axis="migra"), observation)
+        exposure = self.make_exposure_irf(geom.squash(axis_name="migra"), observation)
 
         return make_edisp_map(
             edisp=observation.edisp,
@@ -170,6 +178,34 @@ class MapDatasetMaker:
             exposure_map=exposure,
         )
 
+    def make_edisp_kernel(self, geom, observation):
+        """Make energy dispersion kernel map.
+
+        Parameters
+        ----------
+        geom : `~gammapy.maps.Geom`
+            Reference geom. Must contain "energy" and "energy_true" axes in that order.
+        observation : `~gammapy.data.Observation`
+            Observation container.
+
+        Returns
+        -------
+        edisp : `~gammapy.irf.EDispKernelMap`
+            EdispKernel map.
+        """
+        if isinstance(observation.edisp, EDispKernelMap):
+            exposure = None
+            interp_map = observation.edisp.edisp_map.interp_to_geom(geom)
+            return EDispKernelMap(edisp_kernel_map=interp_map, exposure_map=exposure)
+        exposure = self.make_exposure_irf(geom.squash(axis_name="energy"), observation)
+
+        return make_edisp_kernel_map(
+            edisp=observation.edisp,
+            pointing=observation.pointing_radec,
+            geom=geom,
+            exposure_map=exposure,
+        )
+
     def make_psf(self, geom, observation):
         """Make psf map.
 
@@ -182,15 +218,18 @@ class MapDatasetMaker:
 
         Returns
         -------
-        psf : `~gammapy.cube.PSFMap`
+        psf : `~gammapy.irf.PSFMap`
             Psf map.
         """
         psf = observation.psf
+        if isinstance(psf, PSFMap):
+            return PSFMap(psf.psf_map.interp_to_geom(geom))
+
         if isinstance(psf, EnergyDependentMultiGaussPSF):
-            rad_axis = geom.get_axis_by_name("theta")
+            rad_axis = geom.axes["rad"]
             psf = psf.to_psf3d(rad=rad_axis.center)
 
-        exposure = self.make_exposure_irf(geom.squash(axis="theta"), observation)
+        exposure = self.make_exposure_irf(geom.squash(axis_name="rad"), observation)
 
         return make_psf_map(
             psf=psf,
@@ -199,23 +238,44 @@ class MapDatasetMaker:
             exposure_map=exposure,
         )
 
+    @staticmethod
+    def make_meta_table(observation):
+        """Make info meta table.
+
+        Parameters
+        ----------
+        observation : `~gammapy.data.Observation`
+            Observation
+
+        Returns
+        -------
+        meta_table: `~astropy.table.Table`
+        """
+        meta_table = Table()
+        meta_table["TELESCOP"] = [observation.aeff.meta["TELESCOP"]]
+        meta_table["OBS_ID"] = [observation.obs_id]
+        meta_table["RA_PNT"] = [observation.pointing_radec.icrs.ra.deg] * u.deg
+        meta_table["DEC_PNT"] = [observation.pointing_radec.icrs.dec.deg] * u.deg
+
+        return meta_table
+
     def run(self, dataset, observation):
         """Make map dataset.
 
         Parameters
         ----------
-        dataset : `~gammapy.cube.MapDataset`
+        dataset : `~gammapy.datasets.MapDataset`
             Reference dataset.
         observation : `~gammapy.data.Observation`
             Observation
 
         Returns
         -------
-        dataset : `~gammapy.cube.MapDataset`
+        dataset : `~gammapy.datasets.MapDataset`
             Map dataset.
         """
         kwargs = {"gti": observation.gti}
-
+        kwargs["meta_table"] = self.make_meta_table(observation)
         mask_safe = Map.from_geom(dataset.counts.geom, dtype=bool)
         mask_safe.data |= True
 
@@ -230,11 +290,8 @@ class MapDatasetMaker:
             kwargs["exposure"] = exposure
 
         if "background" in self.selection:
-            background_map = self.make_background(dataset.counts.geom, observation)
-            kwargs["models"] = BackgroundModel(
-                background_map,
-                name=dataset.name + "-bkg",
-                datasets_names=[dataset.name],
+            kwargs["background"] = self.make_background(
+                dataset.counts.geom, observation
             )
 
         if "psf" in self.selection:
@@ -242,7 +299,13 @@ class MapDatasetMaker:
             kwargs["psf"] = psf
 
         if "edisp" in self.selection:
-            edisp = self.make_edisp(dataset.edisp.edisp_map.geom, observation)
+            if dataset.edisp.edisp_map.geom.axes[0].name.upper() == "MIGRA":
+                edisp = self.make_edisp(dataset.edisp.edisp_map.geom, observation)
+            else:
+                edisp = self.make_edisp_kernel(
+                    dataset.edisp.edisp_map.geom, observation
+                )
+
             kwargs["edisp"] = edisp
 
         return MapDataset(name=dataset.name, **kwargs)
