@@ -9,25 +9,28 @@ from .spectral_cosmic_ray import *
 from .spectral_crab import *
 from .temporal import *
 
-SPATIAL_MODELS = Registry(
+SPATIAL_MODEL_REGISTRY = Registry(
     [
         ConstantSpatialModel,
         TemplateSpatialModel,
         DiskSpatialModel,
         GaussianSpatialModel,
+        GeneralizedGaussianSpatialModel,
         PointSpatialModel,
         ShellSpatialModel,
     ]
 )
-"""Built-in spatial models."""
+"""Registry of spatial model classes."""
 
-SPECTRAL_MODELS = Registry(
+SPECTRAL_MODEL_REGISTRY = Registry(
     [
         ConstantSpectralModel,
         CompoundSpectralModel,
         PowerLawSpectralModel,
         PowerLaw2SpectralModel,
+        BrokenPowerLawSpectralModel,
         SmoothBrokenPowerLawSpectralModel,
+        PiecewiseNormSpectralModel,
         ExpCutoffPowerLawSpectralModel,
         ExpCutoffPowerLaw3FGLSpectralModel,
         SuperExpCutoffPowerLaw3FGLSpectralModel,
@@ -35,42 +38,44 @@ SPECTRAL_MODELS = Registry(
         LogParabolaSpectralModel,
         TemplateSpectralModel,
         GaussianSpectralModel,
-        AbsorbedSpectralModel,
+        EBLAbsorptionNormSpectralModel,
         NaimaSpectralModel,
         ScaleSpectralModel,
+        PowerLawNormSpectralModel,
+        LogParabolaNormSpectralModel,
+        ExpCutoffPowerLawNormSpectralModel,
     ]
 )
-"""Built-in spectral models."""
+"""Registry of spectral model classes."""
 
-TEMPORAL_MODELS = Registry([ConstantTemporalModel, LightCurveTemplateTemporalModel,])
-"""Built-in temporal models."""
-
-MODELS = Registry(
-    SPATIAL_MODELS
-    + SPECTRAL_MODELS
-    + TEMPORAL_MODELS
-    + [SkyModel, SkyDiffuseCube, BackgroundModel]
+TEMPORAL_MODEL_REGISTRY = Registry(
+    [
+        ConstantTemporalModel,
+        LightCurveTemplateTemporalModel,
+        ExpDecayTemporalModel,
+        GaussianTemporalModel,
+    ]
 )
-"""All built-in models."""
+"""Registry of temporal models classes."""
+
+MODEL_REGISTRY = Registry([SkyModel, FoVBackgroundModel, BackgroundModel])
+"""Registry of model classes"""
 
 
 __all__ = [
-    "SPATIAL_MODELS",
-    "TEMPORAL_MODELS",
-    "SPECTRAL_MODELS",
-    "SkyModelBase",
+    "MODEL_REGISTRY",
+    "SPATIAL_MODEL_REGISTRY",
+    "TEMPORAL_MODEL_REGISTRY",
+    "SPECTRAL_MODEL_REGISTRY",
     "Models",
     "SkyModel",
-    "SkyDiffuseCube",
-    "BackgroundModel",
     "create_crab_spectral_model",
     "create_cosmic_ray_spectral_model",
-    "Absorption",
     "SpatialModel",
     "SpectralModel",
     "TemporalModel",
 ]
 
-__all__.extend(cls.__name__ for cls in SPATIAL_MODELS)
-__all__.extend(cls.__name__ for cls in SPECTRAL_MODELS)
-__all__.extend(cls.__name__ for cls in TEMPORAL_MODELS)
+__all__.extend(cls.__name__ for cls in SPATIAL_MODEL_REGISTRY)
+__all__.extend(cls.__name__ for cls in SPECTRAL_MODEL_REGISTRY)
+__all__.extend(cls.__name__ for cls in TEMPORAL_MODEL_REGISTRY)
